AdminIntegrationSettings class

Constructors

AdminIntegrationSettings({required AiIntegrationSettings ai, required SmtpIntegrationSettings smtp, required TurnstileIntegrationSettings turnstile, DateTime? updatedAt})
const
AdminIntegrationSettings.fromJson(Map<String, dynamic> json)
factory

Properties

ai AiIntegrationSettings
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smtp SmtpIntegrationSettings
final
turnstile TurnstileIntegrationSettings
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited