AdminReply class

Constructors

AdminReply({required int id, required int surveyResponseId, required String anonymousAccountId, required String body, String? adminId, required DateTime createdAt, DateTime? readAt})
const
AdminReply.fromJson(Map<String, dynamic> json)
factory

Properties

adminId String?
final
anonymousAccountId String
final
body String
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
readAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surveyResponseId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited