Answer class

Constructors

Answer({int? id, required int surveyResponseId, required int questionId, String? textValue, List<int>? selectedChoiceIds, List<String>? fileKeys})
const
Answer.fromJson(Map<String, dynamic> json)
factory

Properties

fileKeys List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
questionId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedChoiceIds List<int>?
final
surveyResponseId int
final
textValue String?
final

Methods

copyWith({int? id, int? surveyResponseId, int? questionId, String? textValue, List<int>? selectedChoiceIds, List<String>? fileKeys}) Answer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited