AuthUserInfo class

Constructors

AuthUserInfo({required UuidValue id, String? email, required List<String> scopeNames, required AdminRole role, required DateTime created})
const
AuthUserInfo.fromJson(Map<String, dynamic> json)
factory

Properties

created DateTime
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
role AdminRole
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeNames List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited