Client class
Properties
- adminSettings ↔ AdminSettingsEndpoint
-
latefinal
- aiAdmin ↔ AiAdminEndpoint
-
latefinal
- anonymous ↔ AnonymousEndpoint
-
latefinal
- auth ↔ ClientAuth
-
latefinal
- authSessionManager ↔ Object?
-
getter/setter pair
- baseUri → Uri
-
final
- choiceAdmin ↔ ChoiceAdminEndpoint
-
latefinal
- config ↔ ConfigEndpoint
-
latefinal
- connectivityMonitor ↔ Object?
-
getter/setter pair
- emailIdp ↔ EmailIdpEndpoint
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- notificationSettings ↔ NotificationSettingsEndpoint
-
latefinal
- projectAdmin ↔ ProjectAdminEndpoint
-
latefinal
- questionAdmin ↔ QuestionAdminEndpoint
-
latefinal
- responseAnalytics ↔ ResponseAnalyticsEndpoint
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- survey ↔ SurveyEndpoint
-
latefinal
- surveyAdmin ↔ SurveyAdminEndpoint
-
latefinal
- userAdmin ↔ UserAdminEndpoint
-
latefinal
Methods
-
close(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rawRequest(
String method, String path, {Map< String, String> ? query, bool authenticated = false, String? bearerToken}) → Future<RawResponse> -
request(
String method, String path, {Object? body, Map< String, String> ? query, bool authenticated = false, String? bearerToken}) → Future -
toString(
) → String -
A string representation of this object.
inherited
-
uploadBytes(
String method, String path, {required List< int> bytes, required String contentType, Map<String, String> ? query, bool authenticated = false, String? bearerToken}) → Future - Upload raw bytes (e.g. image/jpeg) without JSON encoding the body.
-
uriFor(
String path, [Map< String, String> ? query]) → Uri
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- requestTimeout → const Duration