ClientAuth class

Constructors

ClientAuth({required String storageKey, Future<void> revokeSession()?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isAuthenticated bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedInUser AuthUserInfo?
getter/setter pair
token String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore() Future<void>
signOutDevice() Future<void>
toString() String
A string representation of this object.
inherited
updateSignedInUser(AuthSuccess authSuccess) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited