DeviceInfo class

Constructors

DeviceInfo({String? deviceId, String? label, String? platform, String? os, String? osVersion, String? browser, String? browserVersion, String? appVersion, String? appBuild, String? model, String? manufacturer, String? locale, String? timezone, int? screenWidth, int? screenHeight, double? devicePixelRatio, String? userAgent})
const
DeviceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

appBuild String?
final
appVersion String?
final
browser String?
final
browserVersion String?
final
detailSummary String?
no setter
deviceId String?
final
devicePixelRatio double?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
locale String?
final
manufacturer String?
final
model String?
final
os String?
final
osVersion String?
final
platform String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenHeight int?
final
screenWidth int?
final
summary String?
no setter
timezone String?
final
userAgent String?
final

Methods

merge(DeviceInfo? override) DeviceInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited