ResponseAnalyticsEndpoint class

Constructors

ResponseAnalyticsEndpoint(Client _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createReply(int responseId, String body) Future<AdminReply>
deleteResponse(int responseId) Future<bool>
exportResponses(int surveyId, {ResponseExportFormat format = ResponseExportFormat.csv, DateTime? from, DateTime? to}) Future<ResponseExportFile>
getAggregatedResults(int surveyId) Future<SurveyResults>
getAnswersForResponse(int responseId) Future<List<Answer>>
getReplies(int responseId) Future<List<AdminReply>>
getResponseCount(int surveyId) Future<int>
getResponses(int surveyId, {int? limit, int? offset}) Future<List<SurveyResponse>>
getResponseTrends(int surveyId, {int days = 30}) Future<Map<String, int>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited