AdminIntegrationSettingsInput class
Constructors
- AdminIntegrationSettingsInput({AiProvider aiProvider = AiProvider.gemini, String? geminiApiKey, bool clearGeminiApiKey = false, String? openaiApiKey, bool clearOpenaiApiKey = false, String? claudeApiKey, bool clearClaudeApiKey = false, String? groqApiKey, bool clearGroqApiKey = false, String? cerebrasApiKey, bool clearCerebrasApiKey = false, String? smtpHost, int? smtpPort, String? smtpUsername, String? smtpPassword, bool clearSmtpPassword = false, String? smtpFromEmail, String? smtpFromName, SmtpSecureMode smtpSecureMode = SmtpSecureMode.starttls, String? turnstileSiteKey, bool clearTurnstileSiteKey = false, String? turnstileSecretKey, bool clearTurnstileSecretKey = false, DateTime? expectedUpdatedAt})
-
const
Properties
- aiProvider → AiProvider
-
final
- cerebrasApiKey → String?
-
final
- claudeApiKey → String?
-
final
- clearCerebrasApiKey → bool
-
final
- clearClaudeApiKey → bool
-
final
- clearGeminiApiKey → bool
-
final
- clearGroqApiKey → bool
-
final
- clearOpenaiApiKey → bool
-
final
- clearSmtpPassword → bool
-
final
- clearTurnstileSecretKey → bool
-
final
- clearTurnstileSiteKey → bool
-
final
- expectedUpdatedAt → DateTime?
-
updatedAt from the settings snapshot the form was built from; the
server rejects the save with 409 if someone else saved in between.
final
- geminiApiKey → String?
-
final
- groqApiKey → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- openaiApiKey → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smtpFromEmail → String?
-
final
- smtpFromName → String?
-
final
- smtpHost → String?
-
final
- smtpPassword → String?
-
final
- smtpPort → int?
-
final
- smtpSecureMode → SmtpSecureMode
-
final
- smtpUsername → String?
-
final
- turnstileSecretKey → String?
-
final
- turnstileSiteKey → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited