EmailIdpEndpoint class
Constructors
- EmailIdpEndpoint(Client _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
finishPasswordReset(
{required String finishPasswordResetToken, required String newPassword}) → Future< void> -
login(
{required String email, required String password, String? captchaToken}) → Future< AuthSuccess> -
logout(
) → Future< void> - Invalidate the current admin session on the server (best-effort).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startPasswordReset(
{required String email}) → Future< UuidValue> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyPasswordResetCode(
{required UuidValue passwordResetRequestId, required String verificationCode}) → Future< UuidValue>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited